#
# spec file for package fxload
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fxload
Version:        2013_01_03
Release:        2.4
Summary:        Download Firmware into USB FX and FX2 Devices
License:        LGPL-2.1-or-later
Group:          System/Kernel
URL:            https://sourceforge.net/projects/fx3load/
Source0:        %{name}-%{version}.tar.xz
Source1:        generate-tarball.sh
Patch0:         fxload-2002_04_11.patch
# PATCH-FIX-UPSTREAM fxload-2013_01_03-prefer_DEVNAME.patch lp#156085 -- seife+obs@b1-systems.com
Patch1:         fxload-2013_01_03-prefer_DEVNAME.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This program can download firmware into FX, FX2 and FX3
(thanks to the patch from Steven J. Magnani) EZ-USB devices as
well as the original AnchorChips EZ-USB.  It is intended to be invoked
by hotplug scripts when the unprogrammed device appears on the bus.

Primarily as an aid for developers, this can also be used to update
firmware on devices that boot from I2C serial EEPROMs.	For that use,
as well as downloading firmware to all other off-chip memory, a second
stage loader must first be downloaded.

%prep
%autosetup -p1

%build
# use date of .changes file instead of __DATE__
# to avoid useless republishing
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{SOURCE1} '+%%b %%e %%Y')
make %{?_smp_mflags} CC="gcc" CFLAGS="%{optflags} -Wall -g -DFXLOAD_VERSION=\"\\\"$FAKE_BUILDDATE (development)\\\"\""

%install
%make_install
%if 0%{?suse_version} < 1550
mkdir %{buildroot}/sbin
ln -sf %{_sbindir}/fxload %{buildroot}/sbin
%endif

%files
%license COPYING
%doc README.txt
%defattr(-,root,root)
%if 0%{?suse_version} < 1550
/sbin/*
%endif
%attr(755,root,root) %{_sbindir}/fxload
%{_mandir}/man?/*
%dir %{_datadir}/usb
%{_datadir}/usb/a3load.hex

%changelog
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Tue Oct 12 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to v2013_01_03:
  * Switch to a more updated codebase, since the previous one
    has been unmaintained for years and do not support newer devices.
    This codebase is the same as the old fxload but with some small
    changes made by Steven J. Magnani that add support for
    Cypress FX3 USB 3.0 devices.
    This package is needed, for example, by most of the recent
    astronomical cameras (e.g QHY, ZWO, etc), otherwise the OS
    will not be able to recognize them.
- Rebase and rename fxload-2008_10_13-prefer_DEVNAME.patch to fxload-2013_01_03-prefer_DEVNAME.patch
* Thu Nov 26 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Wed Jun  3 2015 mpluskal@suse.com
- Use url with version
- Add changelog as source
- Cleanup spec file with spec-clener
* Mon May 11 2015 dmueller@suse.com
- enable building for all arches
* Sun Jan 12 2014 seife+obs@b1-systems.com
- added patches:
  * fxload-2008_10_13-prefer_DEVNAME.patch
    This uses the more modern DEVNAME variable instead of DEVICE to
    work better with current udev / kernels
- avoid usage of __DATE__ in version output, use modification time
  of .changes file instead
* Wed Feb 15 2012 rschweikert@suse.com
- place binary in the /usr tree (UsrMerge project)
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Mon Feb  1 2010 jengelh@medozas.de
- enable SPARC building
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Wed Oct 29 2008 olh@suse.de
- update to version 2008-10-13
  add support for FX2LP
  enable build on ppc64
* Thu Aug  9 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Tue Jun  5 2007 ro@suse.de
- fix build with current kernel
* Thu Jul 20 2006 olh@suse.de
- include linux/usb_ch9.h, remove linux/version.h usage
* Sat Apr 29 2006 olh@suse.de
- linux/usbdevice_fs.h needs linux/compiler.h for __user
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 uli@suse.de
- enabled for ARM
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Wed Aug 31 2005 ro@suse.de
- removed config-dist.sh and added ExclusiveArch
* Tue Aug 19 2003 olh@suse.de
- initial package version fxload-2002_04_11, split from hotplug.rpm
